@@ -1,4 +1,8 @@
 from pytest_vcr_delete_on_fail.main import (
     get_default_cassette_path,
     has_class_scoped_setup_failed,
-    has_class_scoped_teardown_failed)
+    has_class_scoped_teardown_failed,
+    delete_on_fail,
+    vcr_and_dof,
+    ValidTarget,
+)
